#!perl
#
#
package  File::FileUtil::Drivers::IO;

use strict;
use warnings;
use warnings::register;

use vars qw($VERSION $DATE $FILE );
$VERSION = '0.02';
$DATE = '2003/07/04';
$FILE = __FILE__;

__END_
